part of 'exercise_plan_custom_add_bloc.dart';

@immutable
abstract class ExercisePlanCustomAddEvent extends Equatable {
  const ExercisePlanCustomAddEvent();

  @override
  List<Object> get props => [];
}

class ExercisePlanCustomAddLoad extends ExercisePlanCustomAddEvent {
  const ExercisePlanCustomAddLoad();
}

class ExercisePlanCustomAddChangeSerie extends ExercisePlanCustomAddEvent {
  final double quantity;
  const ExercisePlanCustomAddChangeSerie({required this.quantity});

  @override
  List<Object> get props => [quantity];
}

class ExercisePlanCustomAddChangeQuantity extends ExercisePlanCustomAddEvent {
  final double quantity;
  const ExercisePlanCustomAddChangeQuantity({required this.quantity});

  @override
  List<Object> get props => [quantity];
}

class ExercisePlanCustomAddChangeQuantityUnit extends ExercisePlanCustomAddEvent {
  final double quantity;
  const ExercisePlanCustomAddChangeQuantityUnit({required this.quantity});

  @override
  List<Object> get props => [quantity];
}

class ExercisePlanCustomAddSubmit extends ExercisePlanCustomAddEvent {
  const ExercisePlanCustomAddSubmit();
}

class ExercisePlanCustomAddRemove extends ExercisePlanCustomAddEvent {
  const ExercisePlanCustomAddRemove();
}
